server_client_20141211_234315

### config2 : test_redlining

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.52480697632 sec | 4.73298478127 sec

Error message: server latency too high while sending 10000 integers

Naarad report

### Metrics

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 1794.52 | 1794.52 | 1794.52 | 1794.52 | 1794.52 | 1794.52 | 1794.52 | 1794.52 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.078
server1-perf | latency | mean lt 0.33 | 0.690024975025
server1-perf | qps | mean lt 7.0 | 333.666666667
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1794.522
client1-perf | latency | mean lt 35.0 | 1794.522
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None